import * as model from "@yellicode/model";
import { ModelTransform } from "./model-transform";
/**
 * A base class for transforms that need to be applied recursively to all nested packaged elements
 * in a model or package.
 */
export declare abstract class PackagedElementTransform<TSource extends model.Package = model.Model> implements ModelTransform<TSource, model.Package> {
    /**
     * Transforms the package and returns the transformation result.
     * @param pack The package or model to transform.
     */
    transform(pack: TSource): model.Package;
    /**
     * When implemented, applies the transformation to the packageable element,
     * @param element
     */
    protected abstract transformElement(element: model.PackageableElement): void;
    private transformPackageRecursive(pack);
}
